package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ReportQueryLog;

/**
 * 查询日志Service接口
 * 
 * @author boman
 * @date 2021-12-27
 */
public interface IReportQueryLogService 
{
    /**
     * 查询查询日志
     * 
     * @param logId 查询日志主键
     * @return 查询日志
     */
    public ReportQueryLog selectReportQueryLogByLogId(Long logId);

    /**
     * 查询查询日志列表
     * 
     * @param reportQueryLog 查询日志
     * @return 查询日志集合
     */
    public List<ReportQueryLog> selectReportQueryLogList(ReportQueryLog reportQueryLog);

    /**
     * 新增查询日志
     * 
     * @param reportQueryLog 查询日志
     * @return 结果
     */
    public int insertReportQueryLog(ReportQueryLog reportQueryLog);

    /**
     * 修改查询日志
     * 
     * @param reportQueryLog 查询日志
     * @return 结果
     */
    public int updateReportQueryLog(ReportQueryLog reportQueryLog);

    /**
     * 批量删除查询日志
     * 
     * @param logIds 需要删除的查询日志主键集合
     * @return 结果
     */
    public int deleteReportQueryLogByLogIds(Long[] logIds);

    /**
     * 删除查询日志信息
     * 
     * @param logId 查询日志主键
     * @return 结果
     */
    public int deleteReportQueryLogByLogId(Long logId);
}
